OC.L10N.register(
    "settings",
    {
    "Cancel" : "Cancelar",
    "Password" : "Clave",
    "Username" : "Usuario",
    "Personal" : "Personal",
    "Admin" : "Administración",
    "Error" : "Error",
    "Share" : "Compartir"
},
"nplurals=2; plural=(n != 1);");
